@@ -19,7 +19,8 @@ from .options import Options
 from .Worker import Worker
 from .Fork import Fork
 from .ErrorMs import ErrorMs
-from .Util import validForksConf, getItemBy, Merge
+import time
+from .Util import validForksConf, getItemBy
 from .version_framework import version
 from http.server import BaseHTTPRequestHandler, HTTPServer
 from .types import TypesActions
@@ -270,6 +271,27 @@ class Microservices(BaseClass, ABC):
         except StopIteration as stop:
             return stop.value
 
+    def _send_error(self, data, id_transaction):
+        data_error = {
+            "id": id_transaction,
+            "_id": id_transaction,
+            "error": data,
+            "servicio": self.__TOPIC__,
+            "fecha": int(time.time() * 1000)
+        }
+
+        if isinstance(data, dict):
+            if "error" in data and "_id" in data:
+                data.update(
+                    {"fecha": int(time.time() * 1000)})
+                data_error = data
+
+        self._send(
+            os.environ.get('TOPIC_ERROR_CRITIC', 'Errores_criticos'),
+            data_error,
+            id_transaction
+        )
+
     def json_to_b64(self, json_in):
         """
             Metodo para convertir un diccionaro al formato
@@ -286,7 +308,8 @@ class Microservices(BaseClass, ABC):
         """
 
         if topic == "Errores_criticos":
-            self._send(topic, data, id_transaction)
+            # self._send(topic, data, id_transaction)
+            self._send_error(data, id_transaction)
         else:
 
             id_trans = id_transaction if id_transaction is None else str(
